@@ -66,9 +66,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 namespace ScreenLocker
 {
 
-static const QString s_qtQuickBackend = QStringLiteral("QT_QUICK_BACKEND");
-
-static KSldApp * s_instance = 0;
+static KSldApp * s_instance = nullptr;
 
 KSldApp* KSldApp::self()
 {
@@ -82,8 +80,8 @@ KSldApp* KSldApp::self()
 KSldApp::KSldApp(QObject * parent)
     : QObject(parent)
     , m_lockState(Unlocked)
-    , m_lockProcess(NULL)
-    , m_lockWindow(NULL)
+    , m_lockProcess(nullptr)
+    , m_lockWindow(nullptr)
     , m_waylandServer(new WaylandServer(this))
     , m_waylandDisplay(nullptr)
     , m_lockedTimer(QElapsedTimer())
@@ -169,7 +167,7 @@ void KSldApp::initialize()
     }
 
     // Global keys
-    if (KAuthorized::authorizeKAction(QStringLiteral("lock_screen"))) {
+    if (KAuthorized::authorizeAction(QStringLiteral("lock_screen"))) {
         qDebug() << "Configuring Lock Action";
         QAction *a = new QAction(this);
         a->setObjectName(QStringLiteral("Lock Session"));
@@ -228,8 +226,6 @@ void KSldApp::initialize()
             // failure, restart lock process
             m_greeterCrashedCounter++;
             if (m_greeterCrashedCounter < 4) {
-                // Perhaps it crashed due to a graphics driver issue, force software rendering now
-                setForceSoftwareRendering(true);
                 startLockProcess(EstablishLock::Immediate);
             } else if (m_lockWindow) {
                 m_lockWindow->emergencyShow();
@@ -389,7 +385,6 @@ void KSldApp::lock(EstablishLock establishLock)
 
     m_lockState = AcquiringLock;
 
-    setForceSoftwareRendering(false);
     // start unlock screen process
     startLockProcess(establishLock);
     emit lockStateChanged();
@@ -528,7 +523,7 @@ void KSldApp::doUnlock()
     hideLockWindow();
     // delete the window again, to get rid of event filter
     delete m_lockWindow;
-    m_lockWindow = NULL;
+    m_lockWindow = nullptr;
     m_lockState = Unlocked;
     m_lockedTimer.invalidate();
     m_greeterCrashedCounter = 0;
@@ -551,8 +546,6 @@ bool KSldApp::isFdoPowerInhibited() const
 
 void KSldApp::startLockProcess(EstablishLock establishLock)
 {
-    QProcessEnvironment env = m_greeterEnv;
-
     if (m_isWayland && m_waylandDisplay) {
         int sx[2];
         if (socketpair(AF_UNIX, SOCK_STREAM | SOCK_CLOEXEC, 0, sx) < 0) {
@@ -573,7 +566,9 @@ void KSldApp::startLockProcess(EstablishLock establishLock)
         emit greeterClientConnectionChanged();
         int socket = dup(sx[1]);
         if (socket >= 0) {
+            QProcessEnvironment env = m_greeterEnv;
             env.insert("WAYLAND_SOCKET", QByteArray::number(socket));
+            m_lockProcess->setProcessEnvironment(env);
         }
     }
     QStringList args;
@@ -592,9 +587,6 @@ void KSldApp::startLockProcess(EstablishLock establishLock)
     if (m_lockGrace == -1) {
         args << QStringLiteral("--nolock");
     }
-    if (m_forceSoftwareRendering) {
-        env.insert(s_qtQuickBackend, QStringLiteral("software"));
-    }
 
     // start the Wayland server
     int fd = m_waylandServer->start();
@@ -606,7 +598,6 @@ void KSldApp::startLockProcess(EstablishLock establishLock)
     args << QStringLiteral("--ksldfd");
     args << QString::number(fd);
 
-    m_lockProcess->setProcessEnvironment(env);
     m_lockProcess->start(QStringLiteral(KSCREENLOCKER_GREET_BIN), args);
     close(fd);
 }
